==> aliyun-python-sdk-sas-2.0.1.tar.gz: aliyun-python-sdk-sas-2.0.1/aliyunsdksas/request/v20181203/SetClusterInterceptionConfigRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class SetClusterInterceptionConfigRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'SetClusterInterceptionConfig')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ClusterIds(self): # String
		return self.get_query_params().get('ClusterIds')

	def set_ClusterIds(self, ClusterIds):  # String
		self.add_query_param('ClusterIds', ClusterIds)
	def get_SwitchType(self): # Integer
		return self.get_query_params().get('SwitchType')

	def set_SwitchType(self, SwitchType):  # Integer
		self.add_query_param('SwitchType', SwitchType)
	def get_SwitchOn(self): # Integer
		return self.get_query_params().get('SwitchOn')

	def set_SwitchOn(self, SwitchOn):  # Integer
		self.add_query_param('SwitchOn', SwitchOn)

==> aliyun-python-sdk-sas-2.0.3.tar.gz: aliyun-python-sdk-sas-2.0.3/aliyunsdksas/request/v20181203/SetClusterInterceptionConfigRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class SetClusterInterceptionConfigRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'SetClusterInterceptionConfig','sas')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ClusterIds(self): # String
		return self.get_query_params().get('ClusterIds')

	def set_ClusterIds(self, ClusterIds):  # String
		self.add_query_param('ClusterIds', ClusterIds)
	def get_SwitchType(self): # Integer
		return self.get_query_params().get('SwitchType')

	def set_SwitchType(self, SwitchType):  # Integer
		self.add_query_param('SwitchType', SwitchType)
	def get_SwitchOn(self): # Integer
		return self.get_query_params().get('SwitchOn')

	def set_SwitchOn(self, SwitchOn):  # Integer
		self.add_query_param('SwitchOn', SwitchOn)
